Berikut adalah skema jaringan yang akan dibangun.
|eth0
|
|——-|
| serv |
|—|—|
|
|eth1
|
|
|——————–hub———————-|
| | |
| | |
| | |
|———| |———| |———|
|Client 01| |Client 02| |Client 03|
|———| |———| |———|
Pertama yang harus di lakukan adalah mensetting serv(gateway utama) supaya bisa terhubung ke internet
Sebelum Mensetting :
=[satu]=
Minta IP public ke ISP lengkap dengan netmask,broadcast dan dns nya misalnya :
IP: 202.169.227.45
GATEWAY : 202.169.227.1
Nemast: 255.255.255.192
broadcast : 202.169.227.63
DNS1: 202.168.244.3
DNS2: 202.168.244.4
=[dua]=
Menentukan IP local yang akan kita gunakan buat client
IP: 192.168.0.2 - 192.168.0.254
GATEWAY: 192.168.0.1
NETMASK: 255.255.255.0
BROADCAST: 192.168.0.255
DNS1: 202.168.244.3
DNS2: 202.168.244.4
=[tiga]=
Setting IP serv :
[root@serv root]$ vi /etc/sysconfig/network
untuk mengedit dengan menggunakan editor vi (baca: vi-ai) tekan tombol i atau insert untuk memulai mengedit.
lalu isi dengan :
NETWORKING=yes
HOSTNAME=serv.domain.com
GATEWAY=202.169.227.1
lalu simpan dengan menekan :wq
=[empat]=
Menconfigurasi IP eth0(default)
[root@serv root]$ vi /etc/sysconfig/network-scripts/ifcfg-eth0
untuk mengedit dengan menggunakan editor vi (baca: vi-ai) tekan tombol i atau insert untuk memulai mengedit.
lalu isi dengan :
DEVICE=eth0
BOOTPROTO=static
IPADDR=202.169.227.45
BROADCAST=202.169.227.63
NETMASK=255.255.255.192
ONBOOT=yes
USERCTL=no
lalu simpan dengan menekan :wq
=[lima]=
Setting dns resolve
[root@serv root]$ vi /etc/resolve.conf
untuk mengedit dengan menggunakan editor vi (baca: vi-ai) tekan tombol i atau insert untuk memulai mengedit.
lalu isi dengan nameserver dari isp kita tadi :
nameserver 202.168.244.3
nameserver 202.168.244.4
lalu simpan dengan menekan :wq
=[enam]=
konfigurasi IP eth1
[root@serv root]$ vi /etc/sysconfig/network-scripts/ifcfg-eth1
untuk mengedit dengan menggunakan editor vi (baca: vi-ai) tekan tombol i atau insert untuk memulai mengedit.
lalu isi dengan :
DEVICE=eth1
BOOTPROTO=static
IPADDR=192.168.0.1
BROADCAST=192.168.0.255
NETMASK=255.255.255.0
ONBOOT=yes
USERCTL=no
lalu simpan dengan menekan :wq
=[tujuh]=
Setting ip_forwarding dan masquerading.
[root@serv root]$ vi /etc/rc.d/rc.local
untuk mengedit dengan menggunakan editor vi (baca: vi-ai) tekan tombol i atau insert untuk memulai mengedit.
lalu isi dengan :
echo “1″ > /proc/sys/net/ipv4/ip_forward
/sbin/iptables -t nat -A POSROUTING -s 192.168.0.0/24 [eth0 -j MASQUERADE
=[delapan]=
restart network
[root@serv root]$ service network restart
Shutting down interface eth0: [ OK ]
Shutting down interface eth1: [ OK ]
Shutting down loopback interface: [ OK ]
Disabling IPv4 packet forwarding: [ OK ]
Setting network parameters: [ OK ]
Bringing up loopback interface: [ OK ]
Bringing up interface eth0: [ OK ]
Bringing up interface eth1: [ OK ]
=[sembilan]=
testing dengan ping ke default gateway 202.169.227.1
[root@serv root]$ ping 202.169.227.1
64 bytes from 202.169.227.1 : icmp_seq=1 time=15.4 ms
64 bytes from 202.169.227.1 : icmp_seq=2 time=15.4 ms
64 bytes from 202.169.227.1 : icmp_seq=3 time=15.4 ms
64 bytes from 202.169.227.1 : icmp_seq=4 time=15.4 ms
64 bytes from 202.169.227.1 : icmp_seq=5 time=15.4 ms
64 bytes from 202.169.227.1 : icmp_seq=6 time=15.4 ms
64 bytes from 202.169.227.1 : icmp_seq=7 time=15.4 ms
—– 202.169.227.1 ping statistic —–
6 packets transmites, 6 received, 0% packet loss, time 3049ms
=[sepuluh]=
Testing dengan cara ping ip eth1
[root@serv root]$ ping 192.168.0.1
PING 192.168.0.1 (192.168.0.1) 56(84) bytes of data.
64 bytes from 192.168.0.1: icmp_seq=1 ttl=63 time=0.356 ms
64 bytes from 192.168.0.1: icmp_seq=2 ttl=63 time=0.269 ms
64 bytes from 192.168.0.1: icmp_seq=3 ttl=63 time=0.267 ms
64 bytes from 192.168.0.1: icmp_seq=4 ttl=63 time=0.268 ms
— 192.168.0.1 ping statistics —
4 packets transmitted, 4 received, 0% packet loss, time 2997ms
rtt min/avg/max/mdev = 0.267/0.290/0.356/0.038 ms
=[sebelas]
Tinggal Setting IP computer client dengan ketentuan di bawah ini :
IP: 192.168.0.2 - 192.168.0.254
GATEWAY: 192.168.0.1
NETMASK: 255.255.255.0
BROADCAST: 192.168.0.255
DNS1: 202.168.244.3
DNS2: 202.168.244.4
misal :
Client01
===============================
IP: 192.168.0.2
GATEWAY: 192.168.0.1
NETMASK: 255.255.255.0
BROADCAST: 192.168.0.255
NAMESERVER: 192.168.0.1
Client02
===============================
IP: 192.168.0.3
GATEWAY: 192.168.0.1
NETMASK: 255.255.255.0
BROADCAST: 192.168.0.255
NAMESERVER: 192.168.0.1
dan seterusnya sesuai banyaknya client,yang berubah hanya IP
untuk client windows maka setting IP di bagian Start Menu/Setting/Control Panel/Network
=[duabelas]=
setelah di setting ip client, maka
- ping ke 192.168.0.1 dari client,kalau berhasil berarti client dan router nya sudah tersambung.
- ping ke 202.169.227.45 dari client, kalau berhasil maka fungsi masquerading yang terletak di /etc/rc.d/rc/local telah bekerja dengan baik
namun jika tidak bisa maka Anda harus menjalankan fungsi masquerading yang terletak di /etc/rc.d/rc.local dengan cara :
.- anda bekerja menggunakan router yang anda buat tadi.
.- masuk ke account root
.- jalankan perintah berikut ini, tiap akhir perintah akhiri dengan menekan enter :
[root@serv root]# service network restart
[root@serv root]# /etc/rc.d/rc.local
jika sudah, coba ping ping ke 202.169.227.45 dari client
- selanjutnya ping ke default gateway 202.169.227.1 dari client
- ping ke 202.168.244.3 dari client
- ping ke 202.168.244.4 dari client
kalau semua berhasil maka silakan traktir teman-teman ada untuk makan bersama, karena anda telah selesai membuat router.namun sebelum anda makan-makan, restart router anda apakah bisa bekerja dengan baik atau tidak… sebagai ukuran bekerja
baik tidaknya, setelah Anda restart router tersebut kemudian kalau telah hidup dengan sempurne ping ke 202.168.244.3, kalau mendapatkan jawaban “64 bytes from 202.168.244.3 : icmp_seq=1 time=15.4 ms” silakan ajak teman makan-makan tp kalau jawabannya “request time out” maka silakan anda makan dengan cepat dan kembali bekerja dengan mengecek file /etc/rc.d/rc.local dan IP address dari router…
sekian semoga goresan ini bermanfaat.. dan jangan takut mencoba….
sukses buat semua
Membuat router dengan linuk
Jaringan Komputer
Wireshark merupakan software untuk melakukan analisa lalu-lintas jaringan
komputer, yang memiliki fungsi-fungsi yang amat berguna bagi
profesional jaringan, administrator jaringan, peneliti, hingga
pengembang piranti lunak jaringan. Wireshark dapat membaca data
secara langsung dari Ethernet, Token-Ring, FDDI, serial (PPP and SLIP),
802.11 wireless LAN , dan koneksi ATM.Program ini juga sering digunakan oleh chatters untuk mengetahui ip victimnya maupun para chatter lainnya lewat typingan room.
sekalian taro link ahh wat download softwarenya ^___^
Wireshark
Posted on Senin, Agustus 25, 2008
Labels: Download
Wireshark | 17.8 MB
2. Capture WIreshark
a. Pastikan kita terhubung dengan jaringan network di lingkungan kita, seperti LAN atau WLAN dsb
b. kita jalankan program WireShark
c. Setelah kita masuk di Wireshark kita pilih button
d. Kemudian akan muncul window dimana kita bias memilih interface yang akan kita analisa
e. Klik tombol start
f. Kemudian wireshark akan mulai bekerja
g. Kita buka browser ex. Mozzila, dan kita coba membuka website seperti www.google.com
h. Maka wireshark akan menampilkan data-data yang keluar-masuk pada interface sehingga kita dapat menganalisa data-data tesebut
3. TCP/UDP header
* TCP header
http://www.fatpipe.org/~mjb/Drawings/TCP-Header.png
* UDP header
http://www.fatpipe.org/~mjb/Drawings/UDP-Header.png
4. flow control dan congestion control
* Flow control adalah suatu teknik untuk menjamin bahwa sebuah stasiun pengirim tidak membanjiri stasiun penerima dengan data. Stasiun penerima secara khas akan menyediakan suatu buffer data dengan panjang tertentu. Ketika data diterima, dia harus mengerjakan beberapa poses sebelum dia dapat membersihkan buffer dan mempersiapkan penerimaan data berikutnya.
Bentuk sederhana dari kontrol aliran dikenal sebagai stop and wait, dia bekerja sebagai berikut. Penerima mengindikasikan bahwa dia siap untuk menerima data dengan mengirim sebual poll atau menjawab dengan select. Pengirim kemudian mengirimkan data.
Flow control ini diatur/dikelola oleh Data Link Control (DLC) atau biasa disebut sebagai Line Protocol sehingga pengiriman maupun penerimaan ribuan message dapat terjadi dalam kurun waktu sesingkat mungkin. DLC harus memindahkan data dalam lalu lintas yang efisien. Jalur komunikasi harus digunakan sedatar mungkin, sehingga tidak ada stasiun yang berada dalam kadaan idle sementara stasiun yang lain saturasi dengan lalu lintas yang berkelebihan. Jadi flow control merupakan bagian yang sangat kritis dari suatu jaringan. Berikut ini ditampilkan time diagram Flow control saat komunikasi terjadi pada kondisi tanpa error dan ada error.
* congestion control merupakan pengaturan paket-paket data yang terdistribusi dalam jaringan agar tidak terjadi kepadatan (congestion). Alasan terjadinya congestion antara lain: komputer berkecepatan tinggi mengirimkan data lebih cepat dari pada jaringannya, apabila beberapa komputer mengirimkan data ke tujuan yang sama secara simultan.
5. three way handshake
Proses pada 3 way handshake secara ringkas dapat dituliskan sbb :
a. “initial request” yaitu permintaan unutk mengirim
b. reply (jawaban) dari host yang dituju
c. acknowledge (pengenalan) merupakan jawaban kembali atas reply sebelumnya.
Penjelasan dari 3 babak diatas adalah sebagai berikut :
Step 1
TCP client memulai three-way handshake dengan mengirim segmen dengan sinyal SYN (Synchronize Sequence Number), yang mengindikasikan nilai awal dari nomor sekuensial yang ada pada header. Nilai awal ini dikenal dengan Initial Sequence Number (ISN), digunakan untuk memulai mengirim aliran data dari klien ke server untuk sesi ini.. Nilai ISN pada header dari tiap segmen akan dinaikkan satu setiap data yang dikirim dari client ke server ketika percakapan data.
Step 2
TCP server perlu untuk mengacknowledge SYN segmen yang diterima dari klien untuk membangun sesi dari klien ke server. Maka, server mengirim segmen balik ke klien dengan ACK flag. Klien akan mengenali bahwa server menerima sinyal SYN dari TCP klien.
Step 3
Akhirnya, klien TCP merespon dengan segmen yang berisi ACK yang digunakan untuk merespon TCP SYN yang dikirim oleh server. Ketika kedua sesi telah terbentuk antara klien dan server, semua tambahan segmen yang bertukar pada komunikasi ini akan memiliki ACK flag.
Acknowledgment with windowing pada TCP
Header segmen sequence number dan acknowledgement number digunakan secara bersama untuk mengkonfirmasi byte yang terkandung dalam segmen. Sequence number mengindikasikan jumlah relative dari byte yang telah ditransmisi pada sesi ini termasuk byte yang terkandung dalam segmen. TCP menggunakan acknowledgement number di segments yang dikirm balik ke sumber untuk mengindikasikan byte berikutnya pada sesi ini yang penerima akan mendapatkannya. Ini disebut expectational acknowledgement.
Namun selama sesi tersebut dilakukan, ada pembatasan pengiriman jumlah byte dengan windowing (window size). Window size sendiri adalah banyaknya data yang dapat ditransmisikan oleh pengirim sebelum menerima sinyal acknowledgement.
6. netstat command
Netstat (NETwork STATistics) adalah suatu tool berbasis command line yang digunakan untuk mengetahui konfigurasi suatu jaringan dan aktivitas yang sedang terjadi di jaringan tersebut, serta statistiknya.
Fungsi-fungsi dari netstat bermacam-macam, diantaranya :
a. Untuk menampilkan routing table
b. Untuk menampilkan statistik interface
c. Untuk menampilkan informasi tambahan interface
d. Untuk menamplikan soket network
e. Untuk menampilkan semua soket yg open
f. Untuk menampilkan semua soket yg listen
g. Untuk menampilkan kesimpulan statistik dari tiap protocol
Netstat command mendisplay informasi mengenai trafik pada jaringan interfaces, meliputi:
* Alamat dari blok protocol kendali yang tergabung dengan soket dan status dari semua soket.
* Banyaknya paket yang diterima, ditransmisi, dan di-drop pada suatu subsistem telekomunikasi.
* Statistik kumulatis tiap interface.
* Route dan status-statusnya.
Informasi dibawah ini mwrupakan tambahan untuk mengetahui syntax dan optional yang terdapat pada netstat :
J Untuk menampilkan routing table :
#netstat -rn
-> -r : Kernel routing table
-> -n : Menampilkan alamat numerik.
J Untuk menampilkan statistik interface :
#netstat -i
-> -i : Interface
J Untuk menampilkan informasi tambahan interface :
#netstat -ie
-> -i : Interface
-> -e : Extended information
command ini sama dengan perintah “ifconfig -a”
J Untuk menamplikan soket network :
#netstat -uta
-> -u : UDP
-> -t : TCP
-> -a : ALL
Kemungkinan yg muncul dari status soket adalah sebagai berikut :
ESTABLISHED : Koneksi terjalin
SYN_SENT : Soket berusaha untuk menjalin koneksi
SYN_RECV : Request koneksi sudah diterima dari network
FIN_WAIT1 : Soket close, dan koneksi shutdown
FIN_WAIT2 : Soket close, dan soket menunggu sisi remote shutdown
TIME_WAIT : Soket menunggu setelah close utk menangani paket yg masih di network
CLOSED : Soket tidak digunakan
CLOSE_WAIT : Sisi remote sudah shutdown, menunggu soket close.
LAST_ACK : Sisi remote sudah shutdown, dan soket sudah close, menunggu ack.
LISTEN : Soket sedang menerima koneksi
CLOSING : 2 sisi soket shutwodn
UNKNOWN : Meneketehe
J Untuk menampilkan semua soket yg open (info tambahan) :
#netstat -aute
-> -a : ALL
-> -u : UDP
-> -t : TCP
-> -e : Extended
J Untuk menampilkan semua soket yg listen
# netstat -lt
-> -t : TCP
-> -l : Status soket
JUntuk menampilkan kesimpulan statistik dari tiap protokol
#netstat -s
-> -s : Summary statistik dari tiap protokol
7. connection dan connectionless
Connectionless ialah suatu jenis komunikasi antar unit dalam jaringan yang transmisinya dilakukan tanpa pembentukan hubungan terlebih dahulu. Paket dikirmkan ke penerima tanpa memberi tahu penerima dahulu. Metode yang seperti ini memungkinkan paket yang diterima pada sisi penerima tidak dalam urutan yang sesuai.
Connection-oriented membangun koneksi terlebih dahulu ke penerima sebelum data dikirimkan. Hal ini digunakan untuk komunikasi voice seperti telepon, yang mengharuskan koneksi tetap tersambung meskipun pembicaraan tidak dilakukan.
8. encapsulation
Enkapsulasi adalah sebuah proses menambahkan header dan trailer atau melakukan pemaketan pada sebuah data. Dengan enkapsulasi data menjadi memiliki identitas.
Berikut akan dijelaskan bagaimana jalannya data dari host A menuju host B:
1) Pertama-tama data dibuat oleh Host A. Kemudian data tersebut turun dari Application layer sampai ke physical layer (dalam proses ini data akan ditambahkan header setiap turun 1 lapisan kecuali pada Physical layer, sehingga terjadi enkapsulasi sempurna).
2) Data keluar dari host A menuju kabel dalam bentuk bit (kabel bekerja pada Physical layer).
3) Data masuk ke hub, tetapi data dalam bentuk bit tersebut tidak mengalami proses apa-apa karena hub bekerja pada Physical layer.
4) Setelah data keluar dari hub, data masuk ke switch. Karena switch bekerja pada Datalink layer/ layer 2, maka data akan naik sampai layer 2 kemudian dilakukan proses, setelah itu data turun dari layer 2 kembali ke layer 1/ phisycal layer.
5) Setelah data keluar dari switch, data masuk ke router. Karena router bekerja pada layer 3/ Network layer, maka data naik sampai layer 3 kemudian dilakukan proses, setelah itu data turun dari layer 3 kembali ke layer 1 , dan data keluar dari router menuju kabel dalam bentuk bit.
6) Pada akhirnya data sampai pada host B. Data dalam bentuk bit naik dari layer 1 sampai layer 7. Dalam proses ini data yang dibungkus oleh header-header layer OSI mulai dilepas satu persatu sesuai dengan lapisannya (berlawanan dengan proses no 1 ). Setalah data sampai di layer 7 maka data siap dipakai oleh host B
9. Proses-proses TCP dan UDP
* TCP
File Transfer Protocol/FTP (digunakan untuk saluran data) —-> tranfer file antar PC
Simple Mail Transfer Protocol/SMTP yang digunakan untuk mengirim e-mail —-> email
Hypertext Transfer Protocol/HTTP yang digunakan untuk World Wide Web —-> HTTP://www.blablabla.com
menggunakan protokol TCP karena memerlukan receive yang reliable, sesuai urutan
*UDP
Digunakan untuk
multimedia streaming, yang sangat memberikan toleransi kehilangan segment cukup baik dan yang sangat tidak sensitive terhadap kerusakan atau kehilangan segment
Contoh protokol aplikasi yang menggunakan UDP :
•DNS (Domain Name System) 53
•SNMP, (Simple Network Management Protocol) 161, 162
•TFTP (Trivial File Transfer Protocol) 69
•SunRPC port 111.
10. Port TCP dan UDP
Nomor port TCP Keterangan
20 File Transfer Protocol/FTP (digunakan untuk saluran data)
21 File Transfer Protocol/FTP (digunakan untuk saluran kontrol)
25 Simple Mail Transfer Protocol/SMTP yang digunakan untuk mengirim e-mail
23 Telnet
80 Hypertext Transfer Protocol/HTTP yang digunakan untuk World Wide Web.
110 Post Office Protocol 3/POP3 yang digunakan untuk menerima e-mail.
139 NetBIOS over TCP session service
Nomor Port UDP Digunakan oleh
53 Domain Name System (DNS) Name Query
67 BOOTP client (Dynamic Host Configuration Protocol [DHCP])
68 BOOTP server (DHCP)
69 Trivial File Transfer Protocol (TFTP)
137 NetBIOS Name Service
138 NetBIOS Datagram Service
161 Simple Network Management Protocol (SNMP)
445 Server Message Block (SMB)
520 Routing Information Protocol (RIP)
1812/1813 Remote Authentication Dial-In User Service (RADIUS)
11. Rquest time out dan destination unreachable
a. Request Time Out
Requst Time Out adalah ketika Komputer server tidak merespon permintaan koneksi dari klien setelah beberapa lama (jangka waktu timeout bervariasi) antara lain karena:
RTO (request time out) penyebabnya bermacam2:
1. Utilisasi/pemakaian bandwidth sudah penuh. solusi harus upgrade kecepatan.
2. Kualitas akses jaringan (wireless/wireline) kurang bagus.
3. website yang dituju memiliki delay yang tinggi, sehingga ping timeout.
4.Koneksi ke IP tersebut putus, atau
5. Port di komputer tersebut ditutup.
b. destination unreachable.
Peringatan Destination Unreacable terjadi jika host, jaringan port atau protocol tertentu tidak dapat dijangkau. Akan saya ambil salah satu contoh dari protocol tertenru yang tidak dapat dijangkau. Apabila suatu jaringan menggunakan RIP maka max hop yang dapat ditanganinya adalah 15, apabila melebihi dari itu maka host source akan memberikan pesan error destination unreachable.
Solusi :
1. Periksa, peralatan apa yang hendak diakses, apakah compatible
2. Apakah softwarenya sudah di-install
3. Bila eksternal, setting lokalnya apa sudah benar (ID)
4. Apakah yang dituju sudah siap?
5. Apakah hubungannya sudah benar?
6. Apakah peripheral komunikasi kompatible (speed, ID, metode)
Hari itu q bangun sangat ter gesa-gesa karna belum ngosok,gigi,baju,....He yang lain tak di gosok-gosok.
Mandi habis mandi q tolong ibu.Eh kay lagu aja.Perjalananku menuju cilacap q mulai,q duduk disamping pak kusir yang sedang bekerja,
Naik speda motor yang udud-udud bunyinya,Pake helm "dong" Aku nga mau ketilang lagi.
Wah dalam perjalanan q kedinginan maklumlah bukan kulit badak.Hanya kulit manusia kurus.
Eh sampe juga 25 menit perjalanan.
Walau aku dah ngebut ngebut ak juga masih terlanbat.
Brifing dah dimulai q langsung aja ngikutin.Selesai brifing INilah awal yang menyenangkan and membosankan.
Perjalanan menuju hotel harus ak lalui lewat jalur tikus Abis Ada anak yang alergi pake "helm" sih.
Sampai di hotel.Belum ku kasih tau kita ber8 loh!!!!.Giliran pembagian kamar Disinilah q BAHAGIA.karena,q menempati kamar hanya ber2 yang lainya ber3.
Tepat pukul 14.00.Acara dimulai MAKALAH
KURANG LEBIH SEPERTI INI MAKALAHNYA.
1. MASA REMAJA
Masa remaja merupakan masa dimana seorang individu mengalami
peralihan dari satu tahap ke tahap berikutnya dan mengalami perubahan baik
emosi, tubuh, minat, pola perilaku, dan juga penuh dengan masalah-masalah
(Hurlock, 1998). Oleh karenanya, remaja sangat rentan sekali mengalami masalah
psikososial, yakni masalah psikis atau kejiwaan yang timbul sebagai akibat
terjadinya perubahan sosial (TP-KJM, 2002).
Masa remaja merupakan sebuah periode dalam kehidupan manusia yang
batasannya usia maupun peranannya seringkali tidak terlalu jelas. Pubertas yang
dahulu dianggap sebagai tanda awal keremajaan ternyata tidak lagi valid sebagai
patokan atau batasan untuk pengkategorian remaja sebab usia pubertas yang
dahulu terjadi pada akhir usia belasan (15-18) kini terjadi pada awal belasan
bahkan sebelum usia 11 tahun. Seorang anak berusia 10 tahun mungkin saja
sudah (atau sedang) mengalami pubertas namun tidak berarti ia sudah bisa
dikatakan sebagai remaja dan sudah siap menghadapi dunia orang dewasa. Ia
belum siap menghadapi dunia nyata orang dewasa, meski di saat yang sama ia
juga bukan anak-anak lagi. Berbeda dengan balita yang perkembangannya dengan
jelas dapat diukur, remaja hampir tidak memiliki pola perkembangan yang
pasti. Dalam perkembangannya seringkali mereka menjadi bingung karena
kadang-kadang diperlakukan sebagai anak-anak tetapi di lain waktu mereka
dituntut untuk bersikap mandiri dan dewasa.
Memang banyak perubahan pada diri seseorang sebagai tanda keremajaan,
namun seringkali perubahan itu hanya merupakan suatu tanda-tanda fisik dan
bukan sebagai pengesahan akan keremajaan seseorang. Namun satu hal yang
pasti, konflik yang dihadapi oleh remaja semakin kompleks seiring dengan
perubahan pada berbagai dimensi kehidupan dalam diri mereka. Untuk dapat memahami remaja, maka perlu dilihat berdasarkan perubahan pada dimensi-
dimensi tersebut
Dimensi Biologis
Pada saat seorang anak memasuki masa pubertas yang ditandai dengan
menstruasi pertama pada remaja putri atau pun perubahan suara pada remaja
putra, secara biologis dia mengalami perubahan yang sangat besar. Pubertas
menjadikan seorang anak tiba-tiba memiliki kemampuan untuk ber-reproduksi.
Pada masa pubertas, hormon seseorang menjadi aktif dalam memproduksi
dua jenis hormon (gonadotrophins atau gonadotrophic hormones) yang
berhubungan dengan pertumbuhan, yaitu: 1) Follicle-Stimulating Hormone
(FSH); dan 2). Luteinizing Hormone (LH). Pada anak perempuan, kedua hormon
tersebut merangsang pertumbuhan estrogen dan progesterone: dua jenis hormon
kewanitaan. Pada anak lelaki, Luteinizing Hormone yang juga dinamakan
Interstitial-Cell Stimulating Hormone (ICSH) merangsang pertumbuhan
testosterone.
Pertumbuhan secara cepat dari hormon-hormon tersebut di atas merubah
sistem biologis seorang anak. Anak perempuan akan mendapat menstruasi,
sebagai pertanda bahwa sistem reproduksinya sudah aktif. Selain itu terjadi juga
perubahan fisik seperti payudara mulai berkembang, dll. Anak lelaki mulai
memperlihatkan perubahan dalam suara, otot, dan fisik lainnya yang berhubungan
dengan tumbuhnya hormon testosterone. Bentuk fisik mereka akan berubah
secara cepat sejak awal pubertas dan akan membawa mereka pada dunia remaja.
Dimensi Kognitif
Perkembangan kognitif remaja, dalam pandangan Jean Piaget (seorang ahli
perkembangan kognitif) merupakan periode terakhir dan tertinggi dalam tahap
pertumbuhan operasi formal (period of formal operations).
Pada periode ini, idealnya para remaja sudah memiliki pola pikir sendiri
dalam usaha memecahkan masalah-masalah yang kompleks dan abstrak.
Kemampuan berpikir para remaja berkembang sedemikian rupa sehingga mereka
dengan mudah dapat membayangkan banyak alternatif pemecahan masalah beserta kemungkinan akibat atau hasilnya. Kapasitas berpikir secara logis dan
abstrak mereka berkembang sehingga mereka mampu berpikir multi-dimensi
seperti ilmuwan. Para remaja tidak lagi menerima informasi apa adanya, tetapi
mereka akan memproses informasi itu serta mengadaptasikannya dengan
pemikiran mereka sendiri. Mereka juga mampu mengintegrasikan pengalaman
masa lalu dan sekarang untuk ditransformasikan menjadi konklusi, prediksi, dan
rencana untuk masa depan. Dengan kemampuan operasional formal ini, para
remaja mampu mengadaptasikan diri dengan lingkungan sekitar mereka.
Pada kenyataan, di negara-negara berkembang (termasuk Indonesia) masih
sangat banyak remaja (bahkan orang dewasa) yang belum mampu sepenuhnya
mencapai tahap perkembangan kognitif operasional formal ini. Sebagian masih
tertinggal pada tahap perkembangan sebelumnya, yaitu operasional konkrit,
dimana pola pikir yang digunakan masih sangat sederhana dan belum mampu
melihat masalah dari berbagai dimensi. Hal ini bisa saja diakibatkan sistem
pendidikan di Indonesia yang tidak banyak menggunakan metode belajar-
mengajar satu arah (ceramah) dan kurangnya perhatian pada pengembangan cara
berpikir anak. penyebab lainnya bisa juga diakibatkan oleh pola asuh orangtua
yang cenderung masih memperlakukan remaja sebagai anak-anak, sehingga anak
tidak memiliki keleluasan dalam memenuhi tugas perkembangan sesuai dengan
usia dan mentalnya. Semestinya, seorang remaja sudah harus mampu mencapai
tahap pemikiran abstrak supaya saat mereka lulus sekolah menengah, sudah
terbiasa berpikir kritis dan mampu untuk menganalisis masalah dan mencari solusi
terbaik.
Dimensi Moral
Masa remaja adalah periode dimana seseorang mulai bertanya-tanya
mengenai berbagai fenomena yang terjadi di lingkungan sekitarnya sebagai dasar
bagi pembentukan nilai diri mereka. Elliot Turiel (1978) menyatakan bahwa
para remaja mulai membuat penilaian tersendiri dalam menghadapi masalah-
masalah populer yang berkenaan dengan lingkungan mereka, misalnya: politik,
kemanusiaan, perang, keadaan sosial, dsb. Remaja tidak lagi menerima hasil
pemikiran yang kaku, sederhana, dan absolut yang diberikan pada mereka selama ini tanpa bantahan. Remaja mulai mempertanyakan keabsahan pemikiran yang
ada dan mempertimbangan lebih banyak alternatif lainnya. Secara kritis, remaja
akan lebih banyak melakukan pengamatan keluar dan membandingkannya dengan
hal-hal yang selama ini diajarkan dan ditanamkan kepadanya. Sebagian besar
para remaja mulai melihat adanya “kenyataan” lain di luar dari yang selama ini
diketahui dan dipercayainya. Ia akan melihat bahwa ada banyak aspek dalam
melihat hidup dan beragam jenis pemikiran yang lain. Baginya dunia menjadi
lebih luas dan seringkali membingungkan, terutama jika ia terbiasa dididik dalam
suatu lingkungan tertentu saja selama masa kanak-kanak.
Kemampuan berpikir dalam dimensi moral (moral reasoning) pada remaja
berkembang karena mereka mulai melihat adanya kejanggalan dan
ketidakseimbangan antara yang mereka percayai dahulu dengan kenyataan yang
ada di sekitarnya. Mereka lalu merasa perlu mempertanyakan dan merekonstruksi
pola pikir dengan “kenyataan” yang baru. Perubahan inilah yang seringkali
mendasari sikap "pemberontakan" remaja terhadap peraturan atau otoritas yang
selama ini diterima bulat-bulat. Misalnya, jika sejak kecil pada seorang anak
diterapkan sebuah nilai moral yang mengatakan bahwa korupsi itu tidak baik.
Pada masa remaja ia akan mempertanyakan mengapa dunia sekelilingnya
membiarkan korupsi itu tumbuh subur bahkan sangat mungkin korupsi itu dinilai
baik dalam suatu kondisi tertentu. Hal ini tentu saja akan menimbulkan konflik
nilai bagi sang remaja. Konflik nilai dalam diri remaja ini lambat laun akan
menjadi sebuah masalah besar, jika remaja tidak menemukan jalan
keluarnya. Kemungkinan remaja untuk tidak lagi mempercayai nilai-nilai yang
ditanamkan oleh orangtua atau pendidik sejak masa kanak-kanak akan sangat
besar jika orangtua atau pendidik tidak mampu memberikan penjelasan yang
logis, apalagi jika lingkungan sekitarnya tidak mendukung penerapan nilai-nilai
tersebut.
Peranan orangtua atau pendidik amatlah besar dalam memberikan alternatif
jawaban dari hal-hal yang dipertanyakan oleh putra-putri remajanya. Orangtua
yang bijak akan memberikan lebih dari satu jawaban dan alternatif supaya remaja
itu bisa berpikir lebih jauh dan memilih yang terbaik. Orangtua yang tidak
mampu memberikan penjelasan dengan bijak dan bersikap kaku akan membuat sang remaja tambah bingung. Remaja tersebut akan mencari jawaban di luar
lingkaran orangtua dan nilai yang dianutnya. Ini bisa menjadi berbahaya jika
“lingkungan baru” memberi jawaban yang tidak diinginkan atau bertentangan
dengan yang diberikan oleh orangtua. Konflik dengan orangtua mungkin akan
mulai menajam.
Dimensi Psikologis
Masa remaja merupakan masa yang penuh gejolak. Pada masa ini mood
(suasana hati) bisa berubah dengan sangat cepat. Hasil penelitian di Chicago oleh
Mihalyi Csikszentmihalyi dan Reed Larson (1984) menemukan bahwa remaja
rata-rata memerlukan hanya 45 menit untuk berubah dari mood “senang luar
biasa” ke “sedih luar biasa”, sementara orang dewasa memerlukan beberapa jam
untuk hal yang sama. Perubahan mood (swing) yang drastis pada para remaja ini
seringkali dikarenakan beban pekerjaan rumah, pekerjaan sekolah, atau kegiatan
sehari-hari di rumah. Meski mood remaja yang mudah berubah-ubah dengan
cepat, hal tersebut belum tentu merupakan gejala atau masalah psikologis.
Dalam hal kesadaran diri, pada masa remaja para remaja mengalami perubahan
yang dramatis dalam kesadaran diri mereka (self-awareness). Mereka sangat
rentan terhadap pendapat orang lain karena mereka menganggap bahwa orang lain
sangat mengagumi atau selalu mengkritik mereka seperti mereka mengagumi atau
mengkritik diri mereka sendiri. Anggapan itu membuat remaja sangat
memperhatikan diri mereka dan citra yang direfleksikan (self-image). Remaja
cenderung untuk menganggap diri mereka sangat unik dan bahkan percaya
keunikan mereka akan berakhir dengan kesuksesan dan ketenaran. Remaja putri
akan bersolek berjam-jam di hadapan cermin karena ia percaya orang akan melirik
dan tertarik pada kecantikannya, sedang remaja putra akan membayangkan
dirinya dikagumi lawan jenisnya jika ia terlihat unik dan “hebat”.
Pada usia 16 tahun ke atas, keeksentrikan remaja akan berkurang dengan
sendirinya jika ia sering dihadapkan dengan dunia nyata. Pada saat itu, Remaja
akan mulai sadar bahwa orang lain tenyata memiliki dunia tersendiri dan tidak
selalu sama dengan yang dihadapi atau pun dipikirkannya. Anggapan remaja
bahwa mereka selalu diperhatikan oleh orang lain kemudian menjadi tidak berdasar. Pada saat inilah, remaja mulai dihadapkan dengan realita dan tantangan
untuk menyesuaikan impian dan angan-angan mereka dengan kenyataan.
Para remaja juga sering menganggap diri mereka serba mampu, sehingga
seringkali mereka terlihat “tidak memikirkan akibat” dari perbuatan mereka.
Tindakan impulsif sering dilakukan; sebagian karena mereka tidak sadar dan
belum biasa memperhitungkan akibat jangka pendek atau jangka panjang.
Remaja yang diberi kesempatan untuk mempertangung-jawabkan perbuatan
mereka, akan tumbuh menjadi orang dewasa yang lebih berhati-hati, lebih
percaya-diri, dan mampu bertanggung-jawab. Rasa percaya diri dan rasa
tanggung-jawab inilah yang sangat dibutuhkan sebagai dasar pembentukan jati-
diri positif pada remaja. Kelak, ia akan tumbuh dengan penilaian positif pada diri
sendiri dan rasa hormat pada orang lain dan lingkungan. Bimbingan orang yang
lebih tua sangat dibutuhkan oleh remaja sebagai acuan bagaimana menghadapi
masalah itu sebagai “seseorang yang baru”; berbagai nasihat dan berbagai cara
akan dicari untuk dicobanya. Remaja akan membayangkan apa yang akan
dilakukan oleh para “idola”nya untuk menyelesaikan masalah seperti itu.
Pemilihan idola ini juga akan menjadi sangat penting bagi remaja
Dari beberapa dimensi perubahan yang terjadi pada remaja seperti yang
telah dijelaskan diatas maka terdapat kemungkinan – kemungkinan perilaku yang
bisa terjadi pada masa ini. Diantaranya adalah perilaku yang mengundang resiko
dan berdampak negative pada remaja. Perilaku yang mengundang resiko pada
masa remaja misalnya seperti penggunaan alcohol, tembakau dan zat lainnya;
aktivitas social yang berganti – ganti pasangan dan perilaku menentang bahaya
seperti balapan, selancar udara, dan layang gantung (Kaplan dan Sadock, 1997).
Alasan perilaku yang mengundang resiko adalah bermacam – macam dan
berhubungan dengan dinamika fobia balik ( conterphobic dynamic ), rasa takut
dianggap tidak cakap, perlu untuk menegaskan identitas maskulin dan dinamika
kelompok seperti tekanan teman sebaya.
2. REMAJA DAN ROKOK
Di masa modern ini, merokok merupakan suatu pemandangan yang sangat
tidak asing. Kebiasaan merokok dianggap dapat memberikan kenikmatan bagi si
perokok, namun dilain pihak dapat menimbulkan dampak buruk bagi si perokok
sendiri maupun orang – orang disekitarnya. Berbagai kandungan zat yang terdapat
di dalam rokok memberikan dampak negatif bagi tubuh penghisapnya.
Beberapa motivasi yang melatarbelakangi seseorang merokok adalah untuk
mendapat pengakuan (anticipatory beliefs), untuk menghilangkan kekecewaan (
reliefing beliefs), dan menganggap perbuatannya tersebut tidak melanggar norma
( permissive beliefs/ fasilitative) (Joewana, 2004). Hal ini sejalan dengan kegiatan
merokok yang dilakukan oleh remaja yang biasanya dilakukan didepan orang lain,
terutama dilakukan di depan kelompoknya karena mereka sangat tertarik kepada
kelompok sebayanyaatau dengan kata lain terikat dengan kelompoknya.
Penyebab Remaja Merokok
1. Pengaruh 0rangtua
Salah satu temuan tentang remaja perokok adalah bahwa anak-anak muda yang
berasal dari rumah tangga yang tidak bahagia, dimana orang tua tidak begitu
memperhatikan anak-anaknya dan memberikan hukuman fisik yang keras lebih
mudah untuk menjadi perokok dibanding anak-anak muda yang berasal dari
lingkungan rumah tangga yang bahagia (Baer & Corado dalam Atkinson,
Pengantar psikologi, 1999:294).
2. Pengaruh teman.
Berbagai fakta mengungkapkan bahwa semakin banyak remaja merokok maka
semakin besar kemungkinan teman-temannya adalah perokok juga dan
demikian sebaliknya. Dari fakta tersebut ada dua kemungkinan yang terjadi,
pertama remaja tadi terpengaruh oleh teman-temannya atau bahkan teman-
teman remaja tersebut dipengaruhi oleh diri remaja tersebut yang akhirnya
mereka semua menjadi perokok. Diantara remaja perokok terdapat 87%
mempunyai sekurang-kurangnya satu atau lebih sahabat yang perokok begitu
pula dengan remaja non perokok (Al Bachri, 1991)
3. Faktor Kepribadian.
Orang mencoba untuk merokok karena alasan ingin tahu atau ingin melepaskan
diri dari rasa sakit fisik atau jiwa, membebaskan diri dari kebosanan. Namun
satu sifat kepribadian yang bersifat prediktif pada pengguna obat-obatan
(termasuk rokok) ialah konformitas sosial. Orang yang memiliki skor tinggi
pada berbagai tes konformitas sosial lebih mudah menjadi pengguna
dibandingkan dengan mereka yang memiliki skor yang rendah (Atkinson,
1999).
4. Pengaruh Iklan.
Melihat iklan di media massa dan elektronik yang menampilkan gambaran
bahwa perokok adalah lambang kejantanan atau glamour, membuat remaja
seringkali terpicu untuk mengikuti perilaku seperti yang ada dalam iklan
tersebut. (Mari Juniarti, Buletin RSKO, tahun IX,1991).
3. PENYIMPANGAN SEKS PADA REMAJA
Kita telah ketahui bahwa kebebasan bergaul remaja sangatlah diperlukan
agar mereka tidak "kuper" dan "jomblo" yang biasanya jadi anak mama. "Banyak
teman maka banyak pengetahuan". Namun tidak semua teman kita sejalan dengan
apa yang kita inginkan. Mungkin mereka suka hura-hura, suka dengan yang
berbau pornografi, dan tentu saja ada yang bersikap terpuji.
benar agar kita tidak terjerumus ke pergaulan bebas yang menyesatkan.
Masa remaja merupakan suatu masa yang menjadi bagian dari kehidupan
manusia yang di dalamnya penuh dengan dinamika. Dinamika kehidupan remaja
ini akan sangat berpengaruh terhadap pembentukan diri remaja itu sendiri. Masa
remaja dapat dicirikan dengan banyaknya rasa ingin tahu pada diri seseorang
dalam berbagai hal, tidak terkecuali bidang seks.
Seiring dengan bertambahnya usia seseorang, organ reproduksipun
mengalami perkembangan dan pada akhirnya akan mengalami kematangan.
Kematangan organ reproduksi dan perkembangan psikologis remaja yang mulai
menyukai lawan jenisnya serta arus media informasi baik elektronik maupun non
elektronik akan sangat berpengaruh terhadap perilaku seksual individu remaja
tersebut. Salah satu masalah yang sering timbul pada remaja terkait dengan masa
awal kematangan organ reproduksi pada remaja adalah masalah kehamilan yang
terjadi pada remaja diluar pernikahan. Apalagi apabila Kehamilan tersebut terjadi
pada usia sekolah. Siswi yang mengalami kehamilan biasanya mendapatkan
respon dari dua pihak. Pertama yaitu dari pihak sekolah, biasanya jika terjadi
kehamilan pada siswi, maka yang sampai saat ini terjadi adalah sekolah
meresponya dengan sangat buruk dan berujung dengan dikeluarkannya siswi
tersebut dari sekolah. Kedua yaitu dari lingkungan di mana siswi tersebut tinggal,
lingkungan akan cenderung mencemooh dan mengucilkan siswi tersebut. Hal
tersebut terjadi jika karena masih kuatnya nilai norma kehidupan masyarakat kita.
Kehamilan remaja adalah isu yang saat ini mendapat perhatian pemerintah.
Karena masalah kehamilan remaja tidak hanya membebani remaja sebagai
individu dan bayi mereka namun juga mempengaruhi secara luas pada seluruh
strata di masyarakat dan juga membebani sumber-sumber kesejahteraan. Namun,
alasan-alasannya tidak sepenuhnya dimengerti. Beberapa sebab kehamilan
termasuk rendahnya pengetahuan tentang keluarga berencana, perbedaan budaya
yang menempatkan harga diri remaja di lingkungannya, perasaan remaja akan
ketidakamanan atau impulsifisitas, ketergantungan kebutuhan, dan keinginan yang
sangat untuk mendapatkan kebebasan.
Selain masalah kehamilan pada remaja masalah yang juga sangat
menggelisahkan berbagai kalangan dan juga banyak terjadi pada masa remaja
adalah banyaknya remaja yang mengidap HIV/AIDS
Data dan Fakta HIV/AIDS
Dilihat dari jumlah pengidap dan peningkatan jumlahnya dari waktu ke
waktu, maka dewasa ini HIV (Human Immunodeficiency Virus) dan AIDS
(Acquired Immune Deficiency Syndrome) sudah dapat dianggap sebagai ancaman
hidup bagi masyarakat Indonesia. Berdasarkan laporan Departemen Kesehatan
sampai Juni 2003 jumlah pengidap HIV/AIDS atau ODHA (Orang Yang Hidup
Dengan HIV/AIDS) di Indonesia adalah 3.647 orang terdiri dari pengidap HIV
2.559 dan penderita AIDS 1.088 orang. Dari jumlah tersebut, kelompok usia 15 -
19 berjumlah 151 orang (4,14%); 19-24 berjumlah 930 orang (25,50%). Ini berarti
bahwa jumlah terbanyak penderita HIV/AIDS adalah remaja dan orang muda. Dari data tersebut, dilaporkan yang sudah meninggal karena AIDS secara umum
adalah 394 orang (Subdit PMS & AIDS, Ditjen PPM & PL, Depkes R.I.).
Diperkirakan setiap hari ada 8.219 orang di dunia yang meninggal karena AIDS,
sedangkan di kawasan Asia Pacific mencapai angka1.192orang.
Data dan fakta tersebut belum mencerminkan keadaan yang sebenarnya,
melainkan hanya merupakan "puncak gunung es", artinya, yang kelihatan atau
dilaporkan hanya sedikit, sementara yang tidak kelihatan atau tidak dilaporkan
jumlahnya berkali-kali lipat. Para ahli memperkirakan bahwa jumlah sebenarnya
bisa 100 kali lipat.
Remaja dan HIV/AIDS
Penularan virus HIV ternyata menyebar sangat cepat di kalangan remaja
dan kaum muda. Penularan HIV di Indonesia terutama terjadi melalui hubungan
seksual yang tidak aman, yaitu sebanyak 2.112(58%) kasus. Dari beberapa
penelitian terungkap bahwa semakin lama semakin banyak remaja di bawah usia
18 tahun yang sudah melakukan hubungan seks. Cara penularan lainnya adalah
melalui jarum suntik (pemakaian jarum suntik secara bergantian pada pemakai
narkoba, yaitu sebesar 815 (22,3%) kasus dan melalui transfusi darah 4 (0,10%)
kasus). FKUl-RSCM melaporkan bahwa lebih dari 75% kasus infeksi HIV di
kalangan remaja terjadi di kalangan pengguna narkotika. Jumlah ini merupakan
kenaikan menyolok dibanding beberapa tahun yang lalu.
Beberapa penyebab rentannya remaja terhadap HIV/AIDS adalah
1. Kurangnya informasi yang benar mengenai perilaku seks yang aman dan upaya
pencegahan yang bisa dilakukan oleh remaja dan kaum muda. Kurangnya
informasi ini disebabkan adanya nilai-nilai agama, budaya, moralitas dan lain-
lain, sehingga remaja seringkali tidak memperoleh informasi maupun
pelayanan kesehatan reproduksi yang sesungguhnya dapat membantu remaja
terlindung dari berbagai resiko, termasuk penularan HIV/AIDS.
2. Perubahan fisik dan emosional pada remaja yang mempengaruhi dorongan
seksual. Kondisi ini mendorong remaja untuk mencari tahu dan mencoba-coba
sesuatu yang baru, termasuk melakukan hubungan seks dan penggunaan
narkoba. 3. Adanya informasi yang menyuguhkan kenikmatan hidup yang diperoleh
melalui seks, alkohol, narkoba, dan sebagainya yang disampaikan melalui
berbagai media cetak atau elektronik.
4. Adanya tekanan dari teman sebaya untuk melakukan hubungan seks, misalnya
untuk membuktikan bahwa mereka adalah jantan.
5. Resiko HIV/AIDS sukar dimengerti oleh remaja, karena HIV/AIDS
mempunyai periode inkubasi yang panjang, gejala awalnya tidak segera
terlihat.
6. Informasi mengenai penularan dan pencegahan HIV/AIDS rupanya juga belum
cukup menyebar di kalangan remaja. Banyak remaja masih mempunyai
pandangan yang salah mengenai HIV/AIDS.
7. Remaja pada umumnya kurang mempunyai akses ke tempat pelayanan
kesehatan reproduksi dibanding orang dewasa. Hal tersebut dibuktikan dengan
banyaknya remaja yang terkena HIV/AIDS tidak menyadari bahwa mereka
terinfeksi, kemudian menyebar ke remaja lain, sehingga sulit dikontrol.
Apa sih HIV dan AIDS?
HIV adalah singkatan dari Human Immunodeficiency Virus. Merupakan
virus penyebab AIDS yang melemahka sistem kekebalan tubuh.
AIDS adalah singkatan dari Acquired Immune Deficiency Syndrome yang
merupakan kumpulan dari beberapa gejala akibat menurunnya sistem kekebalan
tubuh yang disebabkan oleh HIV sehingga orang yang telah terinfeksi HIV mudah
diserang berbagai penyakit yang bisa mengancam hidupnya
Perjalanan Infeksi HIV
HIV menular melalui penggunaan jarum suntik secara bergantian, jarum
suntik bekas pakai, jarum suntik yang tidak steril, melakukan hubungan seks
berganti – ganti pasangan, atau proses penularan dari ibu ke bayi melalui proses :
hamil, melahirkan, dan menyusui. Setelah masuk dan menginfeksi manusia
selama 2 minggu sampai 6 bulan ( 3 bulan pada 95% kasus) merupakan masa
antara masuknya HIV ke dalam tubuh sampai terbentuknya antibody (penangkal
penyakit) terhadap HIV atau disebut juga HIV Positif. Pada fase ini HIV sudah
dapat ditularkan kepada orang lain walaupun hasil tes masih negatif. Fase ini disebut fase jendela. Setelah melalaui fase jendela. Selama 3 – 10 tahun setelah
terinfeksi HIV, Seseorang yang telah mengidap HIV Positif tidak
akanmenampakkan gejala, tampak sehat, dan dapat beraktifitas seperti biasa. Baru
setelah 1- 2 tahun kemudian mulai timbul infeksi opportunistik ( penyakit lain
yang muncul karena sistem kekebalan tubuh menurun). Obat ARV ( Anti Retro
Viral ) yang diminum pada fase ini dapat menekan pertumbuhan HIV. Akan tetapi
obat ini tidak dapat menghilangkan HIV dari dalam tubuh.
HIV tidak menular melalui
1. Gigitan nyamuk atau serangga lain
2. Keringat, Sentuhan, Pelukan, ataupun Ciuman
3. Berenang bersama
4. Terpapar batuk atau bersin
5. Berbagi makanan atau menggunakan alat makan bersama
6. Memakai toilet bergantian
Mengetahui status HIV
Status HIV hanya dapat diketahui melalui Konseling dan Testing HIV Sukarela
· Testing HIV merupakan pengambilan darah dan pemeriksaan
laboratorium disertai konseling pre dan pasca testing HIV
· Konseling dan Testing HIV Sukarela dilakukan dengan prinsip tanpa
paksaan, rahasia, tidak membeda-bedakan serta terjamin kualitasnya
· Manfaat Konseling dan Testing HIV Sukarela :
- Mendapat informasi, pelayanan, dan perawatan sesuai kebutuhan
masing-masing sedini mungkin
- Dukungan untuk perubahan perilaku yang lebih sehat dan aman dari
penularan HIV
Sudah adakah obat untuk HIV?
Obat ARV (Anti Retro Viral) dapat mengendalikan pertumbuhan jumlah
HIV dan meningkatkan daya tahan tubuh untuk memperpanjang usia hidup
ODHA ( Orang dengan HIV dan AIDS) Obat ARV tidak dapat menyembuhkan Odha karena tidak bisa
menghilangkan HIV dalam tubuh
Odha harus minum obat ARV secara rutin pada jam tertentu setiap hari dan
seumur hidup
Sejak tahun 2007 terdapat 75 rumah sakit rujukan bagi Odha dis eluruh
Indonesia yang menyediakan obat ARV
\
4. REMAJA DAN PENYALAHGUNAAN MINUMAN KERAS DAN
NARKOBA
Berdasarkan data Badan Narkotika Nasional (BNN),jumlah kasus
penyalahgunaan Narkoba di Indonesia dari tahun 1998 - 2003 adalah 20.301
orang, di mana 70% diantaranya berusia antara 15 -19 tahun
Definisi dan Macam – Macam Narkoba
Narkoba (singkatan dari Narkotika, Psikotropika dan Bahan Adiktif
berbahaya lainnya) adalah bahan/zat yang jika dimasukan dalam tubuh manusia,
baik secara oral/diminum, dihirup, maupun disuntikan, dapat mengubah pikiran,
suasana hati atau perasaan, dan perilaku seseorang. Narkoba dapat menimbulkan
ketergantungan (adiksi ) fisik dan psikologis.
Narkotika adalah zat atau obat yang berasal dari tanaman atau bukan
tanaman, baik sintetis maupun semi sintetis yang dapat menyebabkan penurunan
atau perubahan kesadaran, hilangnya rasa nyeri dan dapat menimbulkan
ketergantungan (Undang-Undang No. 22 tahun 1997).
Yang termasuk jenis Narkotika adalah :
· Tanaman papaver, opium mentah, opium masak (candu, jicing, jicingko),
opium obat, morfina, kokaina, ekgonina, tanaman ganja, dan damar ganja.
· Garam-garam dan turunan-turunan dari morfina dan kokaina, serta
campuran-campuran dan sediaan-sediaan yang mengandung bahan tersebut
di atas.
Psikotropika adalah zat atau obat, baik alamiah maupun sintetis bukan
narkotika, yang berkhasiat psikoaktif melalui pengaruh selektif pada susunan saraf
pusat yang menyebabkan perubahan pada aktivitas mental dan perilaku (Undang-
Undang No. 5/1997). Zat yang termasuk psikotropika antara lain: · Sedatin (Pil BK), Rohypnol, Magadon, Valium, Mandarax, Amfetamine,
Fensiklidin, Metakualon, Metifenidat, Fenobarbital, Flunitrazepam, Ekstasi,
Shabu-shabu, LSD (Lycergic Alis Diethylamide), dsb.
Bahan Adiktif berbahaya lainnya adalah bahan-bahan alamiah, semi sintetis
maupun sintetis yang dapat dipakai sebagai pengganti morfina atau kokaina yang
dapat mengganggu sistim syaraf pusat, seperti: Alkohol.
Apakah Alkohol itu?
Alkohol adalah zat penekan susuan syaraf pusat meskipun dalam jumlah kecil
mungkin mempunyai efek stimulasi ringan
Bahan psikoaktif yang terdapat dalam alkohol adalah etil alkohol yang diperoleh
dari proses fermentasi madu, gula sari buah atau umbi umbian. Nama yang
populer : minuman keras (miras), kamput, tomi (topi miring), cap tikus , balo dll.
Minuman beralkohol mempunyai kadar yang berbeda-beda, misalnya bir dan soda
alkohol ( 1-7% alkohol), anggur (10-15% alkohol) dan minuman keras yang biasa
disebut dengan spirit (35 – 55% alkohol). Konsentrasi alkohol dalam darah
dicapai dalam 30 – 90 menitsetelah diminum.
Dari beberapa penelitian alkohol dapat menyebabkan :
Kecelakaan lalu lintas
Luka bakar
Kasus penganiayaan anak
Bunuh diri
Kecelakaan kerja
Di Indonesia penjualan minuman beralkohol di batasi dan yang boleh membeli
adalah mereka yang telah berumur 21 tahun
Beberapa etnik di Indonesia menggunakan minuman beralkohol pada acara
tertentu dalam jumlah yang sedikit. Mereka juga memproduksi minuman
beralkohol dengan nama yang bermacam ragam misalnya : tuak, minuman cap
tikus, ciu dll
Pengaruh Terhadap Tubuh (Fisik dan Mental)
Pengaruh alkohol terhadap tubuh bervariasi, tergantung pada beberapa faktor
yaitu :
Jenis dan jumlah alkohol yang dikonsumsi
Usia, berat badan, dan jenis kelamin
Makanan yang ada di dalam lambung
Pengalaman seseorang minum – minuman beralkohol
Situasi dimana orang minum – minuman beralkohol
Pengaruh jangka pendek
Walaupun pengaruh terhadap individu berbeda – beda, terdapat hubungan antara
konsentrasi alkohol di dalam darah (Blood Alkohol Concentration – BAC) dan
efeknya. Euphoria ringan dan stimulasi terhadap perilaku lebih aktif seiring
dengan meningkatnya konsentrasi alkohol di dalam darah. Sayangnya orang
banyak beranggapan bahwa penampilan mereka menjadi lebih baik dan mereka
mengabaikan efek buruknya.\
Resiko intoksikasi (”mabuk”)
Gejala intoksikasi alkohol yang paling umum adalah ”mabuk”, ”teler” sehingga
dapat menyebabkan cedera dan kematian. Penurunan kesadaran seperti koma
dapat terjadi pada keracunan alkohol yang berat demikian juga henti nafas dan
kematian.
Selain kematian, efek jangka pendek alkohol dapat menyebabkan hilangny
produktifitas kerja (misalnya ”teler, kecelakaan akibat ngebut). Sebagai tambahan,
alkohol dapat menyebabkan perilaku kriminal. 70 % dari narapidana
menggunakan alkohol sebelum melakukan tindak kekerasan dan lebih dari 40 %
kekerasan dalam rumah tangga dipengaruhi oleh alkohol
Pengaruh Jangka Panjang
Mengkonsumsi alkohol berlebiha dalam jangka panjang dapat menyebabkan :
Kerusakan jantung
Tekanan Darah Tinggi Stroke
Kerusakan hati
Kanker saluran pencernaan
Gangguan pencernaan lainnya (misalnya tukak lambung)
Impotensi dan berkurangnya kesuburan
Meningkatnya resiko terkena kanker payudara
Kesulitan tidur
Kerusakan otak dengan perubahan kepribadian dan suasana perasaan
Sulit dalam mengingat dan berkonsentrasi
Sebagai tambahan terhadap masalah kesehatan, alkohol juga berdampak terhadap
hubungan sesama, finansial, pekerjaan, dan juga menimbulkan masalah hukum
Pengaruh alkohol pada perilaku
Konsentrasi alkohol dalam
darah
Pengaruh yang ditimbulkan
Perasaan
segar (well –
being)
Sampai dengan 0.50 g% · Banyak bicara
· Santai
· Lebih percaya diri
Risiko
rendah
0.05 – 0.08 g % · Banyak bicara
· Bertindak dan lebih merasa
percaya diri
· Berkurangnya kemampuan
untuk berfikir dan bergerak
· Berkurangnya rasa malu
Risiko
sedang
0.08 – 0.15 g % · Bicara cadel
· Berkurangnya keseimbangan
dan koordinasi tubuh
· Refleks menjadi lambat
· Penglihatan kabur
· Emosi yang labil
· Mual, muntah - muntah
Risiko tinggi 0.15 – 0.30 g % · Tidak dapat berjalan tanpa bantuan
· Apatis, mengantuk
· Kesulitan bernafas
· Tidak dapat mengingat
beberapa kejadian
· Tidak dapat mengendalikan
buang air kecil
· Kemungkinan kehilangan
kesadaran
· Koma
· Kematian
Kematian > 0.3 g %
Toleransi dan Ketergantungan
Pengguna alkohol yang terus menerus dapat mengalami toleransi dan
ketergantungan. Toleransi adalah peningkatan penggunaan alkohol dari jumlah
yang kecil menjadi lebih besar untuk mendapatkan pengaruh yang sama.
Sedangkan ketergantungan adalah keadaan dimana alkohol menjadi bagian yang
penting dalam kehidupannya, banyak waktu yang terbuang karena memikirkan
(cara mendapatkan, mengkonsumsi dan bagaimana cara berhenti). Pengguna
alkohol akan mengalami kesulitan bagaimana cara menghentikan atau
mengendalikan jumlah alkohol yang dikonsumsi.
Gejala Putus Alkohol
Seseorang yang mengalami ketergantungan secara fisik terhadap alkohol akan
mengalami gejala putus alkohol apabila menghentikan atau mengurangi
penggunaannya. Gejala biasanya terjadi mulai 6 – 24 jam setelah minum yang
terakhir. Gejala ini dapat berlangsung selama 5 hari, diantaranya adalah :
· Gemetar
· Mual
· Cemas
· Depresi · Berkeringat yang banyak
· Nyeri kepala
· Sulit tidur (berlangsung beberapa minggu)
Gejala putus alkohol sangat berbahaya. Orang yang minum lebih dari 8 standar
minum perhari dianjurkan untuk berkonsultasi ke dokter (sebelum memutuskan
untuk berhenti minum) untuk mendapatkan terapi medis guna mencegah
komplikasi
Sedangkan berdasarkan efeknya, narkoba bisa dibedakan menjadi tiga:
1. Depresan, yaitu menekan sistem sistem syaraf pusat dan mengurangi
aktifitas fungsional tubuh sehingga pemakai merasa tenang, bahkan bisa
membuat pemakai tidur dan tak sadarkan diri. Bila kelebihan dosis bisa
mengakibatkan kematian. Jenis narkoba depresan antara lain opioda, dan
berbagai turunannya seperti morphin dan heroin. Contoh yang populer
sekarang adalah Putaw.
2. Stimulan, merangsang fungsi tubuh dan meningkatkan kegairahan serta
kesadaran. Jenis stimulan: Kafein, Kokain, Amphetamin. Contoh yang
sekarang sering dipakai adalah Shabu-shabu dan Ekstasi.
3. Halusinogen, efek utamanya adalah mengubah daya persepsi atau
mengakibatkan halusinasi. Halusinogen kebanyakan berasal dari tanaman
seperti mescaline dari kaktus dan psilocybin dari jamur-jamuran. Selain itu
ada jugayang diramu di laboratorium seperti LSD. Yang paling banyak
dipakai adalah marijuana atau ganja.
Penyalahgunaan Narkoba
Kebanyakan zat dalam narkoba sebenarnya digunakan untuk pengobatan
dan penelitian. Tetapi karena berbagai alasan – mulai dari keinginan untuk dicoba
– coba, ikut trend/gaya, lambing status social, ingin melupakan persoalan dll –
maka narkoba kemudian disalahgunakan. Penggunaan terus menerus dan berlanjut
akan menyebabkan ketergantungan atau dependensi yang disebut juga dengan
kecanduan. Tingkatan penyalahgunaan biasanya sebagai berikut: 1) coba-coba; 2)
senang-senang; 3) menggunakan pada saat atau keadaan tertentu; 4)
penyalahgunaan; 5) ketergantungan.
Dampak Penyalahgunaan Narkoba
Bila narkoba digunakan secara terus menerus atau melebihi takaran yang
telah ditentukan akan mengakibatkan ketergantungan. Kecanduan inilah yang
akan mengakibatkan gangguan fisik dan psikologis, karena terjadinya kerusakan
pada sistem syaraf pusat (SSP) dan organ-organ tubuh seperti jantung, paru-paru,
hati dan ginjal.
Dampak penyalahgunaan narkoba pada seseorang sangat tergantung pada
jenis narkoba yang dipakai, kepribadian pemakai dan situasi atau kondisi
pemakai. Secara umum, dampak kecanduan narkoba dapat terlihat pada fisik,
psikis maupun sosial seseorang.
1. Dampak Fisik:
1. Gangguan pada system syaraf (neurologis) seperti: kejang-kejang,
halusinasi, gangguan kesadaran, kerusakan syaraf tepi
2. Gangguan pada jantung dan pembuluh darah (kardiovaskuler) seperti:
infeksi akut otot jantung, gangguan peredaran darah
3. Gangguan pada kulit (dermatologis) seperti: penanahan (abses), alergi,
eksim
4. Gangguan pada paru-paru (pulmoner) seperti: penekanan fungsi
pernapasan, kesukaran bernafas, pengerasan jaringan paru-paru
5. Sering sakit kepala, mual-mual dan muntah, murus-murus, suhu tubuh
meningkat, pengecilan hati dan sulit tidur
6. Dampak terhadap kesehatan reproduksi adalah gangguan padaendokrin,
seperti: penurunan fungsi hormon reproduksi (estrogen, progesteron,
testosteron), serta gangguan fungsi seksual
7. Dampak terhadap kesehatan reproduksi pada remaja perempuan antara lain
perubahan periode menstruasi, ketidakteraturan menstruasi, dan
amenorhoe (tidak haid) 8. Bagi pengguna narkoba melalui jarum suntik, khususnya pemakaian jarum
suntik secara bergantian, risikonya adalah tertular penyakit seperti
hepatitis B, C, dan HIV yang hingga saat ini belum ada obatnya
9. Penyalahgunaan narkoba bisa berakibat fatal ketika terjadi Over Dosis
yaitu konsumsi narkoba melebihi kemampuan tubuh untuk menerimanya.
Over dosis bisa menyebabkan kematian
2. Dampak Psikis:
1. Lamban kerja, ceroboh kerja, sering tegang dan gelisah
2. Hilang kepercayaan diri, apatis, pengkhayal, penuh curiga
3. Agitatif, menjadi ganas dan tingkah laku yang brutal
4. Sulit berkonsentrasi, perasaan kesal dan tertekan
5. Cenderung menyakiti diri, perasaan tidak aman, bahkan bunuh diri
3. Dampak Sosiai:
1. Gangguan mental, anti-sosial dan asusila, dikucilkan oleh lingkungan
2. Merepotkan dan menjadi beban keluarga
3. Pendidikan menjadi terganggu, masa depan suram
Dampak fisik, psikis dan sosial berhubungan erat. Ketergantungan fisik
akan mengakibatkan rasa sakit yang luar biasa (sakaw) bila terjadi putus obat
(tidak mengkonsumsi obat pada waktunya) dan dorongan psikologis berupa
keinginan sangat kuat untuk mengkonsumsi (bahasa gaulnya sugest). Gejata fisik
dan psikologis ini juga berkaitan dengan gejala sosial seperti dorongan untuk
membohongi orang tua, mencuri, pemarah, manipulatif, dll.
Bahaya Narkoba Bagi Remaja
Masa remaja merupakan suatu fase perkembangan antara masa anak-anak
dan masa dewasa. Perkembangan seseorang dalam masa anak-anak dan remaja
akan membentuk perkembangan diri orang tersebut di masa dewasa. Karena itulah
bila masa anak-anak dan remaja rusak karena narkoba, maka suram atau bahkan
hancurlah masa depannya.
Pada masa remaja, justru keinginan untuk mencoba-coba, mengikuti trend
dan gaya hidup, serta bersenang-senang besar sekali. Walaupun semua
kecenderungan itu wajar-wajar saja, tetapi hal itu bisa juga memudahkan remaja untuk terdorong menyalahgunakan narkoba. Data menunjukkan bahwa jumlah
pengguna narkoba yang paling banyak adalah kelompok usia remaja.
Masalah menjadi lebih gawat lagi bila karena penggunaan narkoba, para
remaja tertular dan menularkan HIV/AIDS di kalangan remaja. Hal ini telah
terbukti dari pemakaian narkoba melalui jarum suntik secara bergantian. Bangsa
ini akan kehilangan remaja yang sangat banyak akibat penyalahgunaan narkoba
dan merebaknya HIV/AIDS. Kehilangan remaja sama dengan kehilangan sumber
daya manusia bagi bangsa.
5. MENANGANI MASALAH YANG TERJADI PADA REMAJA
Selain ketiga masalah psikososial yang sering terjadi pada remaja seperti
yang disebutkan dan dibahas diatas terdapat pula masalah masalah lain pada
remaja seperti tawuran, kenakalan remaja, kecemasan, menarik diri, kesulitan
belajar, depresi dll.
Semua masalah tersebut perlu mendapat perhatian dari berbagai pihak
mengingat remaja merupakan calon penerus generasi bangsa. Ditangan remaja lah
masa depan bangsa ini digantungkan.
Terdapat beberapa cara yang dapat dilakukan dalam upaya untuk mencegah
semakin meningkatnya masalah yang terjadi pada remaja, yaitu antara lain :
Peran Orangtua :
· Menanamkan pola asuh yang baik pada anak sejak prenatal dan balita
· Membekali anak dengan dasar moral dan agama
· Mengerti komunikasi yang baik dan efektif antara orangtua – anak
· Menjalin kerjasama yang baik dengan guru
· Menjai tokoh panutan bagi anak baik dalam perilaku maupun dalam hal
menjaga lingkungan yang sehat
· Menerapkan disiplin yang konsisten pada anak
· Hindarkan anak dari NAPZA
Peran Guru :
· Bersahabat dengan siswa
· Menciptakan kondisi sekolah yang nyaman · Memberikan keleluasaan siswa untuk mengekspresikan diri pada kegiatan
ekstrakurikuler
· Menyediakan sarana dan prasarana bermain dan olahraga
· Meningkatkan peran dan pemberdayaan guru BP
· Meningkatkan disiplin sekolah dan sangsi yang tegas
· Meningkatkan kerjasama dengan orangtua, sesama guru dan sekolah lain
· Meningkatkan keamanan terpadu sekolah bekerjasama dengan Polsek
setempat
· Mewaspadai adanya provokator
· Mengadakan kompetisi sehat, seni budaya dan olahraga antar sekolah
· Menciptakan kondisi sekolah yang memungkinkan anak berkembang
secara sehat dalah hal fisik, mental, spiritual dan sosial
· Meningkatkan deteksi dini penyalahgunaan NAPZA
Peran Pemerintah dan masyarakat :
· Menghidupkan kembali kurikulum budi pekerti
· Menyediakan sarana/prasarana yang dapat menampung agresifitas anak
melalui olahraga dan bermain
· Menegakkan hukum, sangsi dan disiplin yang tegas
· Memberikan keteladanan
· Menanggulangi NAPZA, dengan menerapkan peraturan dan hukumnya
secara tegas
· Lokasi sekolah dijauhkan dari pusat perbelanjaan dan pusat hiburan
Peran Media :
· Sajikan tayangan atau berita tanpa kekerasan (jam tayang sesaui usia)
· Sampaikan berita dengan kalimat benar dan tepat (tidak provokatif)
· Adanya rubrik khusus dalam media masa (cetak, elektronik) yang bebas
biaya khusus untuk remaja
6. REMAJA DAN PERILAKU HIDUP SEHAT
Remaja yang bersikap hidup sehat adalah remaja:
1. Mengerti tujuan hidup
2. Memahami faktor penghambat maupun pendukung perkembangan
kematangannya.
3. Bergaul dengan bijaksana
4. Terus menerus memperbaiki diri
Dengan demikian remaja dapat diharapkan menjaga remaja yang handal dan
sehat. Remaja harus mengetahui dirinya memiliki kekhawatiran dan harapan,
dengan kata lain remaja harus mengerti dirinya sendiri.
Faktor yang berkembang pada setiap remaja antara lain fisik, intelektual,
emosional, spiritual. Kecepatan perkembangan tersebut adalah sebagai berikut:
1. Fisik 35%
2. Intelektual 20%
3. Emosional 30%
4. Spiritual 15%
Faktor fisik berkembang secara tepat sedangkan faktor lainnya berkembang
tidak sama besar. Perkembangan yang tidak seimbang inilah yang menimbulkan
kejanggalan dan berpengaruh terhadap perilaku remaja.
Bagaimana seseorang remaja melihat dirinya sendiri, orang lain serta
hubungannya dengan orang lain termasuk orang tua dan pembina? Kadang-
kadang ia ingin dianggap sebagai anak-anak, orang dewasa, orang lain dianggap
sebagai orang tua, teman.
Hubungan dirinya dengan orang lain dianggap bersifat:
1. Otoriter ------- demokratis
2. Tertutup ------- terbuka
3. Formal ------- informal
Semua tersebut di atas dalam keadaan "dalam perjalanan menuju" Sehingga dapat
dilihat segalanya masih dalam proses dan tidak berada dalam kutub atau masa
anak-anak ataupun kutub atau masa dewasa.
"Dalam perjalanan menuju" ini yang menonjol adalah:
1. Fisik yang kuat
2. Emosi yang cepat tersinggung
3. Sering mengambil keputusan tanpa berfikir panjang
4. Pertimbangan agama, falsafah, ataupun tatakrama hanya kadang-kadang
saja dipakai
Dan "Dalam perjalanan menuju" yang paling penting diketahui oleh remaja
adalahbagaimana remaja dapat berproses :
1. Menuju fisik yang ideal
2. Menuju emosi kelakian ataupun kewanitaan yang utuh
3. Menuju cara berfikir dewasa
4. Menuju mempercayai hal-hal yang agamais, bersifat falsafah dan bersifat
tatakrama
DAFTAR PUSTAKA
Atkinson (1999). Pengantar Psikologi. Jakarta: Penerbit Erlangga.
Direktorat Kesehatan Jiwa Masyarakat (2001). Buku Pedoman Umum Tim
Pembina, Tim Pengarah & Tim Pelaksana Kesehatan Jiwa. Direproduksi oleh
Proyek Peningkatan Kesehatan Khusus APBD 2002.
Hurlock, E.B (1998). Perkembangan Anak. Alih bahasa oleh Soedjarmo &
Istiwidayanti. Jakarta: Erlangga.
Kozier, B (1991). Fundamental of Nursing : Concept, Process, and Practice.
Fourth Edition. California : Addison-Wesley Publishing Company.
Mappiare, A. (1992). Psikologi Remaja. Surabaya: Usaha Nasional.
Stuart & Sundeen (1998). Principle and Practice of Psychiatric Nursing. 6 th. Ed.
Philadelphia: The C V Mosby.
Azwar, S. 2002. Sikap Manusia, Teori Dan Pengukurannya. Yogyakarta. Pustaka
Pelajar Offset
Kaplan dan Sadock.1997. Sinopsis Psikiatri Ilmu Pengetahuan Perilaku Psikiatri
Klinis (Edisi ke 7, Jilid 1). Jakarta. Binarupa Aksara.
BKKBN. 2001. Remaja Mengenai Dirinya. Jakarta. BKKBN
Dep. Kesehatan RI. 1997. AIDS di Tempat Kerja. Jakarta
UNESCO and UNAIDS. 2002. HIV/AIDS and Education: A Too/kit for
Ministries of Education
Tes Wawancara, Jawabane Mencret..!!
Oleh Redaksi
Jumat, 28 Desember 2007 17:54
HRD manager lagi nyaring berkas lamaran nggo ngisi lowongan nang kantore. Sewise maca kabeh berkas-berkas mau nganti teliti karo temenanan deweke wis nemokna calon-calon sing wis dianggep memenuhi syarat. Dheweke wis nentukna pilihan sing jumlahe 4 (papat).
HRD Manager mau arep ngetes calon-calon sing jumlahe papat mau tapi mung siji sing bakal ketampa. Lha nggo nentukna sapa sing bakalan ketampa deweke arep ngajokna petakonan karo jawaban-jawaban sekang calon-calon mau sing arep nentukna sapa sing bakal ditampa, jawaban sing paling bener karo paling ketemu nalar sing bisa ditampa nang kantore deweke.
Dina wis ditentukna calon sing jumlahe papat mau wis njagong rapi nang ruang wawancara. Manager mau ngajokna petakonan sing jumlahe mung siji : "Menurutmu apa sing mlayune paling cepet?" kuwe petakonane.
Calon 1 : "Pikiran!" Sebab tekane ora dinyana nang njero pikiran, ijig-ijig wis teka! Cepet banget mbok?
Manager : Bagus.Bagus..jawabanmu apik, bisa ditampa. Kowe calon 2 apa jawabanmu..???
Calon2 : "Kejapan mata!" (bahasa Cilacape apa si ya..nyong bingung) tekane ora bisa diramal. Matane dewek sekeplasan wis tekan! Kuwe paling cepet menurutku..
Manager : Wah.kuwe ya jawaban apik..tur mlebu nalar.., calon 3 apa jawabanmu..???
Calon 3 : "Lampu listrik murub!" Kuwe sing paling cepet..aku sering nyeklekna saklar. Lampu sing adoh jarake langsung murub wektu kuwe juga..kuwe sing paling cepet menurutku..
Manager : wah…pancen angel ngalahna cepete murub-e lampu..jawabane bermutu kabeh. Bagus….bagus…, siki kowe calon 4 apa jawabanmu..??
Calon 4 : "Mencreet… pak Manager!"
Manager : Hah….mencret.????(si Manager kaget krungu jawabane calon 4 sing ketone asal-asalan)
Calon 4 : Aja gumun disit!! Kiye aku bisa njelasna alasanku..rong ndina kepungkur wetengku ijig-ijig mules, inyong ngibrit maring WC, tapi during sempat Mikir, Ngejapna mata karo Ngurubna lampu…, mencret wis tekan kathok-ku..!! Berarti "Mencret" lewih cepet sekang "Pikiran, Kejapan mata karo Lampu murub..!"
Manager : Calon 4 sing ketampa..liyane bali.....
Artikel dikirim oleh : Agus Swasana
Pengertian Subneting
Subnetting adalah termasuk materi yang banyak keluar di ujian CCNA dengan berbagai variasi soal. Juga menjadi momok bagi student atau instruktur yang sedang menyelesaikan kurikulum CCNA 1 program CNAP (Cisco Networking Academy Program). Untuk menjelaskan tentang subnetting, saya biasanya menggunakan beberapa ilustrasi dan analogi yang sudah kita kenal di sekitar kita. Artikel ini sengaja saya tulis untuk rekan-rekan yang sedang belajar jaringan, yang mempersiapkan diri mengikuti ujian CCNA, dan yang sedang mengikuti pelatihan CCNA 1.Setelah selesai membaca ini, silakan lanjutkan dengan artikel Penghitungan Subnetting, Siapa Takut?.
Sebenarnya subnetting itu apa dan kenapa harus dilakukan? Pertanyaan ini bisa dijawab dengan analogi sebuah jalan. Jalan bernama Gatot Subroto terdiri dari beberapa rumah bernomor 01-08, dengan rumah nomor 08 adalah rumah Ketua RT yang memiliki tugas mengumumkan informasi apapun kepada seluruh rumah di wilayah Jl. Gatot Subroto.
Ketika rumah di wilayah itu makin banyak, tentu kemungkinan menimbulkan keruwetan dan kemacetan. Karena itulah kemudian diadakan pengaturan lagi, dibuat gang-gang, rumah yang masuk ke gang diberi nomor rumah baru, masing-masing gang ada Ketua RTnya sendiri-sendiri. Sehingga ini akan memecahkan kemacetan, efiesiensi dan optimalisasi transportasi, serta setiap gang memiliki previledge sendiri-sendiri dalam mengelola wilayahnya. Jadilah gambar wilayah baru seperti di bawah:
Konsep seperti inilah sebenarnya konsep subnetting itu. Disatu sisi ingin mempermudah pengelolaan, misalnya suatu kantor ingin membagi kerja menjadi 3 divisi dengan masing-masing divisi memiliki 15 komputer (host). Disisi lain juga untuk optimalisasi dan efisiensi kerja jaringan, karena jalur lalu lintas tidak terpusat di satu network besar, tapi terbagi ke beberapa ruas-ruas gang. Yang pertama analogi Jl Gatot Subroto dengan rumah disekitarnya dapat diterapkan untuk jaringan adalah seperti NETWORK ADDRESS (nama jalan) dan HOST ADDRESS (nomer rumah). Sedangkan Ketua RT diperankan oleh BROADCAST ADDRESS (192.168.1.255), yang bertugas mengirimkan message ke semua host yang ada di network tersebut.
Masih mengikuti analogi jalan diatas, kita terapkan ke subnetting jaringan adalah seperti gambar di bawah. Gang adalah SUBNET, masing-masing subnet memiliki HOST ADDRESS dan BROADCAST ADDRESS.
Terus apa itu SUBNET MASK? Subnetmask digunakan untuk membaca bagaimana kita membagi jalan dan gang, atau membagi network dan hostnya. Address mana saja yang berfungsi sebagai SUBNET, mana yang HOST dan mana yang BROADCAST. Semua itu bisa kita ketahui dari SUBNET MASKnya. Jl Gatot Subroto tanpa gang yang saya tampilkan di awal bisa dipahami sebagai menggunakan SUBNET MASK DEFAULT, atau dengan kata lain bisa disebut juga bahwa Network tersebut tidak memiliki subnet (Jalan tanpa Gang). SUBNET MASK DEFAULT ini untuk masing-masing Class IP Address adalah sbb:
CLASS OKTET PERTAMA SUBNET MAS DEFAULT PRIVATE ADDRESS
A 1-127 255.0.0.0 10.0.0.0-10.255.255.255
B 128-191 255.255.0.0 172.16.0.0-172.31.255.255
C 192-223 255.255.255.0 192.168.0.0-192.168.255.255
Sumber: azdika
Perbedaan Kabel Cross dan Straight
1. Pendahuluan
Seringkali kita dihadapkan pada permasalahan yang mungkin nampak sepele tetapi bisa berakibat fatal di kemudian hari.Bagi sebagian orang ( termasuk saya dulu) menyambung kabel UTP dengan konektor RJ45 cukuplah asal dua ujungnya berwarna sama pasti sudah bukan masalah. Akan tetapi di dalam jaringan yang kompleks dan melibatkan banyak orang tentulah hal tersebut bisa menjadikan masalah dan terjadi keruwetan. Karena itu penting dilakukan standarisasi pemasangan. Tentu kita tidak perlu membuat aturan standard sendiri karena sudah ada lembaga yang mengelola hal tersebut yaitu TIA/EIA, http://www.tiaonline.org/standards/catalog/ dan tinggal kita mengikutinya.
Kabel UTP (Unshielded Twisted Pair) yang lazim dipakai adalah kabel UTP categori 5 (UTP Cat 5) yang secara praktis bisa support transfer data hingga 100 Mbps. UTP Cat 5 terdiri atas4 pasang kabel berwarna atau 8 kabel tunggal. warna kabel tersebut adalah sbb :
Pasangan 1 Putih-Biru dan Biru
Pasangan 2 Putih-orange dan Orange Pasangan 3 Putih-Hijau dan Hijau Pasangan 4 Putih-Coklat dan Coklat
Gambar 1. Urutan Kabel UTP Standard EIA/TIA-568B
2. Standar pemasangan EIA/TIA-568B RJ-45
Mengacu pada standard EIA/TIA-568B maka urutan pemasangan kabel UTP Straight
Seperti gambar 2. Untuk kabel straight(standard) dua ujung kabel memiliki urutan yang sama.
Untuk Kabel cross over urutannya pin 1 dan 3 tukar posisi, ping 2 dan 6 tukar posisi. Atau urutan seperti pada gambar 3.
Ujung 1 standard
Pin 1 Putih-Orange
Pin 2 Orange
Pin 3 Putih-Hijau
Pin 4 Biru
Pin 5 Biru-putih pin 6 Hijau
pin 7 Putih-Cokelat pin 8 Cokelat
Ujung 2 standard
Pin 1 Putih-Orange
Pin 2 Orange
Pin 3 Putih-Hijau
Pin 4 Biru
Pin 5 Biru-putih pin 6 Hijau
pin 7 Putih-Cokelat pin 8 Cokelat
Gambar 2. Urutan Kabel UTP Straight Standard EIA/TIA-568B
Ujung 1 standard
Pin 1 Putih-Orange
Pin 2 Orange
Pin 3 Putih-Hijau
Pin 4 Biru
Pin 5 Biru-putih pin 6 Hijau
pin 7 Putih-Cokelat pin 8 Cokelat
Ujung 2 cross over
Pin 1 Putih-Hijau
Pin 2 Hijau
Pin 3 Orange-Putih
Pin 4 Biru
Pin 5 Biru-putih pin 6 Orange
pin 7 Putih-Cokelat pin 8 Cokelat
Gambar 3. Urutan Kabel UTP Cross Over Standard EIA/TIA-568B
3. Standar pemasangan EIA/TIA-568A RJ-45
Mengacu pada standar EIA/TIA-568A urutan kabelnya adalah sebagai berikut :
Pin 1 Putih-Hijau
Pin 2 Hijau
Pin 3 Putih-Orange
Pin 4 Biru
Pin 5 Biru-putih pin 6 Orange
pin 7 Putih-Cokelat pin 8 Cokelat
Gambar 4. Susunan Kabel UTP Standard EIA/TIA-568A
Untuk kabel Straigth kedua ujung memiliki urutan sbb:
Ujung 1
Pin 1 Putih-Hijau
Pin 2 Hijau
Pin 3 Putih-Orange
Pin 4 Biru
Pin 5 Biru-putih pin 6 Orange
pin 7 Putih-Cokelat pin 8 Cokelat
Ujung 2
Pin 1 Putih-Hijau
Pin 2 Hijau
Pin 3 Putih-Orange
Pin 4 Biru
Pin 5 Biru-putih pin 6 Orange
pin 7 Putih-Cokelat pin 8 Cokelat
Gambar 5. Susunan Kabel UTP Straight Standard EIA/TIA-568A
Untuk Kabel Cross Over urutan sbb :
Ujung 1 Standard
Pin 1 Putih-Hijau
Pin 2 Hijau
Pin 3 Putih-Orange
Pin 4 Biru
Pin 5 Biru-putih pin 6 Orange
pin 7 Putih-Cokelat pin 8 Cokelat
Ujung 2 cross over
Pin 1 Putih-Orange
Pin 2 Orange
Pin 3 Putih- Hijau
Pin 4 Biru
Pin 5 Biru-putih pin 6 Hijau
pin 7 Putih-Cokelat pin 8 Cokelat
Gambar 6. Susunan Kabel UTP Cross Over Standard EIA/TIA-568A
Referensi :
http://www.practicallynetworked.com/howto/040506diy_cables.htm
http://www.netspec.com/helpdesk/wiredoc.html
http://www.ablecables.com.au/568avb.htm
7 Layer OSI Jaringan
Model referensi jaringan terbuka OSI atau OSI Reference Model for open networking adalah sebuah model arsitektural jaringan yang dikembangkan oleh badan International Organization for Standardization (ISO) di Eropa pada tahun 1977. OSI sendiri merupakan singkatan dari Open System Interconnection. Model ini disebut juga dengan model "Model tujuh lapis OSI" (OSI seven layer model).
Sebelum munculnya model referensi OSI, sistem jaringan komputer sangat tergantung kepada pemasok (vendor). OSI berupaya membentuk standar umum jaringan komputer untuk menunjang interoperatibilitas antar pemasok yang berbeda. Dalam suatu jaringan yang besar biasanya terdapat banyak protokol jaringan yang berbeda. Tidak adanya suatu protokol yang sama, membuat banyak perangkat tidak bisa saling berkomunikasi.
Model referensi ini pada awalnnya ditujukan sebagai basis untuk mengembangkan protokol-protokol jaringan, meski pada kenyataannya inisatif ini mengalami kegagalan. Kegagalan itu disebabkan oleh beberapa faktor berikut:
* Standar model referensi ini, jika dibandingkan dengan model referensi DARPA (Model Internet) yang dikembangkan oleh Internet Engineering Task Force (IETF), sangat berdekatan. Model DARPA adalah model basis protokol TCP/IP yang populer digunakan.
* Model referensi ini dianggap sangat kompleks. Beberapa fungsi (seperti halnya metode komunikasi connectionless) dianggap kurang bagus, sementara fungsi lainnya (seperti flow control dan koreksi kesalahan) diulang-ulang pada beberapa lapisan.
* Pertumbuhan Internet dan protokol TCP/IP (sebuah protokol jaringan dunia nyata) membuat OSI Reference Model menjadi kurang diminati.
Pemerintah Amerika Serikat mencoba untuk mendukung protokol OSI Reference Model dalam solusi jaringan pemerintah pada tahun 1980-an, dengan mengimplementasikan beberapa standar yang disebut dengan Government Open Systems Interconnection Profile (GOSIP). Meski demikian. usaha ini akhirnya ditinggalkan pada tahun 1995, dan implementasi jaringan yang menggunakan OSI Reference model jarang dijumpai di luar Eropa.
OSI Reference Model pun akhirnya dilihat sebagai sebuah model ideal dari koneksi logis yang harus terjadi agar komunikasi data dalam jaringan dapat berlangsung. Beberapa protokol yang digunakan dalam dunia nyata, semacam TCP/IP, DECnet dan IBM Systems Network Architecture (SNA) memetakan tumpukan protokol (protocol stack) mereka ke OSI Reference Model. OSI Reference Model pun digunakan sebagai titik awal untuk mempelajari bagaimana beberapa protokol jaringan di dalam sebuah kumpulan protokol dapat berfungsi dan berinteraksi.
Layer Ke- 7 Application layer Berfungsi sebagai antarmuka dengan aplikasi dengan fungsionalitas jaringan, mengatur bagaimana aplikasi dapat mengakses jaringan, dan kemudian membuat pesan-pesan kesalahan. Protokol yang berada dalam lapisan ini adalah HTTP, FTP, SMTP, dan NFS.
Layer Ke- 6 Presentation layer Berfungsi untuk mentranslasikan data yang hendak ditransmisikan oleh aplikasi ke dalam format yang dapat ditransmisikan melalui jaringan. Protokol yang berada dalam level ini adalah perangkat lunak redirektor (redirector software), seperti layanan Workstation (dalam Windows NT) dan juga Network shell (semacam Virtual Network Computing (VNC) atau Remote Desktop Protocol (RDP)).
Layer Ke- 5 Session layer Berfungsi untuk mendefinisikan bagaimana koneksi dapat dibuat, dipelihara, atau dihancurkan. Selain itu, di level ini juga dilakukan resolusi nama.
Layer Ke- 4 Transport layer Berfungsi untuk memecah data ke dalam paket-paket data serta memberikan nomor urut ke paket-paket tersebut sehingga dapat disusun kembali pada sisi tujuan setelah diterima. Selain itu, pada level ini juga membuat sebuah tanda bahwa paket diterima dengan sukses (acknowledgement), dan mentransmisikan ulang terhadp paket-paket yang hilang di tengah jalan.
Layer Ke- 3 Network layer Berfungsi untuk mendefinisikan alamat-alamat IP, membuat header untuk paket-paket, dan kemudian melakukan routing melalui internetworking dengan menggunakan router dan switch layer-3.
Layer Ke- 2 Data-link layer Befungsi untuk menentukan bagaimana bit-bit data dikelompokkan menjadi format yang disebut sebagai frame. Selain itu, pada level ini terjadi koreksi kesalahan, flow control, pengalamatan perangkat keras (seperti halnya Media Access Control Address (MAC Address)), dan menetukan bagaimana perangkat-perangkat jaringan seperti hub, bridge, repeater, dan switch layer 2 beroperasi. Spesifikasi IEEE 802, membagi level ini menjadi dua level anak, yaitu lapisan Logical Link Control (LLC) dan lapisan Media Access Control (MAC).
Layer Ke- 1 Physical layer Berfungsi untuk mendefinisikan media transmisi jaringan, metode pensinyalan, sinkronisasi bit, arsitektur jaringan (seperti halnya Ethernet atau Token Ring), topologi jaringan dan pengabelan. Selain itu, level ini juga mendefinisikan bagaimana Network Interface Card (NIC) dapat berinteraksi dengan media kabel atau radio.
Sumber : http://sipiyuku.woowhosting.com